@@ -46,9 +46,9 @@ class Api(snappi.Api):
 
     # Maps port names used in Snappi to port index for T-Rex
     def loadPorts(self):
-        if 'ports' in self.cfgObj:
+        if 'ports' in self.cfg:
             i = 0
-            for p in self.cfgObj['ports']:
+            for p in self.cfg['ports']:
                 self.portIndices[p['name']] = i
                 i += 1
 
@@ -117,7 +117,7 @@ class Api(snappi.Api):
         """Set or update the configuration
         """
         self.c = STLClient()
-        self.cfgObj = json.loads(config.serialize())
+        self.cfg = json.loads(config.serialize())
         self.loadPorts()
 
         try:
@@ -128,7 +128,7 @@ class Api(snappi.Api):
             self.c.reset(ports = list(self.portIndices.values()))
 
             # for each Snappi flow, construct the equivalent T-Rex stream
-            for f in self.cfgObj["flows"]:
+            for f in self.cfg["flows"]:
                 
                 # Configure variable manager commands
                 vmCmds = []
